@@ -53,7 +53,7 @@ file_remove_thread_func (GTask        *task,
   GFile *file = source_object;
   g_autofree gchar *path = g_file_get_path (file);
 
-  nftw (path, ftw_remove_cb, 20, FTW_DEPTH);
+  nftw (path, ftw_remove_cb, 20, FTW_PHYS | FTW_DEPTH);
 
   if (g_task_set_return_on_cancel (task, FALSE))
     g_task_return_boolean (task, TRUE);
@@ -143,14 +143,12 @@ file_size_finish (GFile        *file,
 }
 
 void
-container_remove_all (GtkContainer *container)
+listbox_remove_all (GtkListBox *listbox)
 {
-  g_autoptr(GList) children = NULL;
-  GList *l;
+  GtkWidget *child;
 
-  children = gtk_container_get_children (container);
-  for (l = children; l; l = l->next)
-    gtk_widget_destroy (GTK_WIDGET (l->data));
+  while ((child = gtk_widget_get_first_child (GTK_WIDGET (listbox))))
+    gtk_list_box_remove (listbox, child);
 }
 
 static gchar *
@@ -168,7 +166,7 @@ get_output_of (const gchar **argv)
                      &status, NULL))
     return NULL;
 
-  if (!g_spawn_check_exit_status (status, NULL))
+  if (!g_spawn_check_wait_status (status, NULL))
     return NULL;
 
   return g_steal_pointer (&output);
