@@ -306,11 +306,11 @@ add_input_source_rows_for_locale (CcInputChooser *self,
 }
 
 static void
-on_back_row_click_released_cb (GtkGestureClick *click,
+on_back_row_click_released_cb (CcInputChooser  *self,
                                int              n_press,
                                double           x,
                                double           y,
-                               CcInputChooser  *self)
+                               GtkGestureClick *click)
 {
   GtkWidget *widget;
   GtkListBoxRow *row;
@@ -332,13 +332,12 @@ show_input_sources_for_locale (CcInputChooser *self,
       GtkEventController *controller;
 
       info->back_row = g_object_ref_sink (back_row_new (info->name));
-      gtk_widget_show (GTK_WIDGET (info->back_row));
       g_object_set_data (G_OBJECT (info->back_row), "back", GINT_TO_POINTER (TRUE));
       g_object_set_data (G_OBJECT (info->back_row), "locale-info", info);
 
       controller = GTK_EVENT_CONTROLLER (gtk_gesture_click_new ());
       gtk_gesture_single_set_button (GTK_GESTURE_SINGLE (controller), 0);
-      g_signal_connect (controller, "released", G_CALLBACK (on_back_row_click_released_cb), self);
+      g_signal_connect_swapped (controller, "released", G_CALLBACK (on_back_row_click_released_cb), self);
       gtk_widget_add_controller (GTK_WIDGET (info->back_row), controller);
     }
   gtk_list_box_append (self->input_sources_listbox, GTK_WIDGET (info->back_row));
@@ -386,7 +385,7 @@ show_locale_rows (CcInputChooser *self)
       if (!info->locale_row)
         {
           info->locale_row = g_object_ref_sink (locale_row_new (info->name));
-          gtk_widget_show (GTK_WIDGET (info->locale_row));
+          gtk_widget_set_visible (GTK_WIDGET (info->locale_row), TRUE);
           g_object_set_data (G_OBJECT (info->locale_row), "locale-info", info);
 
           if (!self->showing_extra &&
@@ -611,7 +610,7 @@ on_filter_entry_search_changed_cb (CcInputChooser *self)
 static void
 show_more (CcInputChooser *self)
 {
-  gtk_widget_show (GTK_WIDGET (self->filter_entry));
+  gtk_widget_set_visible (GTK_WIDGET (self->filter_entry), TRUE);
   gtk_widget_grab_focus (GTK_WIDGET (self->filter_entry));
 
   self->showing_extra = TRUE;
@@ -688,7 +687,6 @@ add_default_row (CcInputChooser *self,
   info->default_input_source_row = input_source_row_new (self, type, id);
   if (info->default_input_source_row)
     {
-      gtk_widget_show (GTK_WIDGET (info->default_input_source_row));
       g_object_ref_sink (GTK_WIDGET (info->default_input_source_row));
       g_object_set_data (G_OBJECT (info->default_input_source_row), "default", GINT_TO_POINTER (TRUE));
       g_object_set_data (G_OBJECT (info->default_input_source_row), "locale-info", info);
@@ -721,7 +719,6 @@ add_rows_to_table (CcInputChooser *self,
       if (g_strcmp0 (id, default_id))
         {
           row = input_source_row_new (self, type, id);
-          gtk_widget_show (GTK_WIDGET (row));
           if (row)
             {
               g_object_set_data (G_OBJECT (row), "locale-info", info);
@@ -1021,7 +1018,7 @@ on_filter_entry_key_release_event_cb (CcInputChooser *self, GdkEventKey *event)
   if (event->keyval == GDK_KEY_Escape) {
     self->showing_extra = FALSE;
     gtk_entry_set_text (GTK_ENTRY (self->filter_entry), "");
-    gtk_widget_hide (GTK_WIDGET (self->filter_entry));
+    gtk_widget_set_visible (GTK_WIDGET (self->filter_entry), FALSE);
     g_clear_pointer (&self->filter_words, g_strfreev);
     show_locale_rows (self);
   }
@@ -1094,15 +1091,12 @@ cc_input_chooser_new (gboolean      is_login,
     self->ibus_engines = g_hash_table_ref (ibus_engines);
 
   self->more_row = g_object_ref_sink (more_row_new ());
-  gtk_widget_show (GTK_WIDGET (self->more_row));
   self->no_results = g_object_ref_sink (no_results_widget_new ());
-  gtk_widget_show (self->no_results);
 
   gtk_list_box_set_filter_func (self->input_sources_listbox, list_filter, self, NULL);
   gtk_list_box_set_sort_func (self->input_sources_listbox, list_sort, self, NULL);
 
-  if (self->is_login)
-    gtk_widget_show (GTK_WIDGET (self->login_label));
+  gtk_widget_set_visible (GTK_WIDGET (self->login_label), self->is_login);
 
   get_locale_infos (self);
 #ifdef HAVE_IBUS
