@@ -1144,6 +1144,9 @@ on_permission_changed (CcUserPanel *self)
                 if (self->fingerprint_manager)
                         fingerprint_state = cc_fingerprint_manager_get_state (self->fingerprint_manager);
 
+                gtk_widget_set_sensitive (GTK_WIDGET (self->user_avatar), TRUE);
+                remove_unlock_tooltip (GTK_WIDGET (self->user_avatar));
+
                 gtk_widget_set_sensitive (GTK_WIDGET (self->user_avatar_edit_button), TRUE);
                 remove_unlock_tooltip (GTK_WIDGET (self->user_avatar_edit_button));
 
@@ -1158,6 +1161,9 @@ on_permission_changed (CcUserPanel *self)
                 remove_unlock_tooltip (GTK_WIDGET (self->fingerprint_row));
         }
         else {
+                gtk_widget_set_sensitive (GTK_WIDGET (self->user_avatar), FALSE);
+                add_unlock_tooltip (GTK_WIDGET (self->user_avatar));
+
                 gtk_widget_set_sensitive (GTK_WIDGET (self->user_avatar_edit_button), FALSE);
                 add_unlock_tooltip (GTK_WIDGET (self->user_avatar_edit_button));
 
@@ -1185,8 +1191,6 @@ setup_main_window (CcUserPanel *self)
                                  self,
                                  NULL);
 
-        add_unlock_tooltip (GTK_WIDGET (self->user_avatar));
-
         self->permission = (GPermission *)polkit_permission_new_sync (USER_ACCOUNTS_PERMISSION, NULL, NULL, &error);
         if (self->permission != NULL) {
                 g_signal_connect_object (self->permission, "notify",
