@@ -22,6 +22,8 @@
 
 #include "cc-wacom-tool.h"
 
+#include <glib/gi18n.h>
+
 enum {
 	PROP_0,
 	PROP_SERIAL,
@@ -165,7 +167,10 @@ cc_wacom_tool_initable_init (GInitable     *initable,
 			tool->id = ids[0];
 	}
 
-	tool->wstylus = libwacom_stylus_get_for_id (wacom_db, tool->id);
+	if (tool->id == 0)
+		tool->wstylus = libwacom_stylus_get_for_id (wacom_db, 0xfffff);
+	else
+		tool->wstylus = libwacom_stylus_get_for_id (wacom_db, tool->id);
 
 	if (!tool->wstylus) {
 		g_set_error (error, 0, 0, "Stylus description not found");
@@ -302,5 +307,24 @@ cc_wacom_tool_get_has_eraser (CcWacomTool *tool)
 {
 	g_return_val_if_fail (CC_IS_WACOM_TOOL (tool), FALSE);
 
-	return libwacom_stylus_has_eraser (tool->wstylus);
+	return libwacom_stylus_is_eraser (tool->wstylus);
+}
+
+const gchar *
+cc_wacom_tool_get_description (CcWacomTool *tool)
+{
+	WacomAxisTypeFlags axes;
+
+	axes = libwacom_stylus_get_axes (tool->wstylus);
+
+	if ((~axes & (WACOM_AXIS_TYPE_TILT | WACOM_AXIS_TYPE_PRESSURE | WACOM_AXIS_TYPE_SLIDER)) == 0)
+		return _("Airbrush stylus with pressure, tilt, and integrated slider");
+	else if ((~axes & (WACOM_AXIS_TYPE_TILT | WACOM_AXIS_TYPE_PRESSURE | WACOM_AXIS_TYPE_ROTATION_Z)) == 0)
+		return _("Airbrush stylus with pressure, tilt, and rotation");
+	else if ((~axes & (WACOM_AXIS_TYPE_TILT | WACOM_AXIS_TYPE_PRESSURE)) == 0)
+		return _("Standard stylus with pressure and tilt");
+	else if ((~axes & WACOM_AXIS_TYPE_PRESSURE) == 0)
+		return _("Standard stylus with pressure");
+
+	return NULL;
 }
